Function Annotations
********************

For programming in general, function parameters drive a function's
dynamic behavior; a function's output depends normally on its inputs.
With :py:mod:`uplink`, function arguments parametrize an HTTP request,
and you indicate the dynamic parts of the request by appropriately
annotating those arguments with the classes detailed in this section.

Path
====

.. autoclass:: uplink.Path

Query
=====

.. autoclass:: uplink.Query

QueryMap
========

.. autoclass:: uplink.QueryMap

Header
======

.. autoclass:: uplink.Header

HeaderMap
=========

.. autoclass:: uplink.HeaderMap

Field
=====

.. autoclass:: uplink.Field


FieldMap
========

.. autoclass:: uplink.FieldMap

Part
====

.. autoclass:: uplink.Part

PartMap
=======

.. autoclass:: uplink.PartMap

Body
====

.. autoclass:: uplink.Body

Url
===

.. autoclass:: uplink.Url

Timeout
=======

.. autoclass:: uplink.Timeout

Context
=======

.. autoclass:: uplink.Context
